#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['jeepney', 'jeepney.integrate', 'jeepney.tests']

package_data = \
{'': ['*']}

setup(name='jeepney',
      version='0.4',
      description='Low-level, pure Python DBus protocol wrapper.',
      author='Thomas Kluyver',
      author_email='thomas@kluyver.me.uk',
      url='https://gitlab.com/takluyver/jeepney',
      packages=packages,
      package_data=package_data,
      python_requires='>=3.5',
     )
